@@ -1,10 +1,13 @@
 # All helpers in the module
 from b4sh import *
 import readline
+from math import ceil
 
 
 def req_get(url):
     """
+    A simple method to make a GET request
+    With a try-except if the request doesn't succeed
 
     :param url:
     :return:
@@ -18,6 +21,8 @@ def req_get(url):
 
 def req_post(url, dat):
     """
+    A simple method to make a POST request
+    With a try-except if the request doesn't succeed
 
     :param url:
     :param dat:
@@ -32,6 +37,7 @@ def req_post(url, dat):
 
 def rlinput(prompt, prefill=''):
     """
+    Same as input  but will add a prefill as a placehoder
 
     :param prompt:
     :param prefill:
@@ -44,21 +50,9 @@ def rlinput(prompt, prefill=''):
         readline.set_startup_hook()
 
 
-def get_stats(payload: dict):
-    """
-
-    :param payload:
-    :return:
-    """
-    print("[=] Stats:")
-    print("[=] ____used_count: {}".format(payload["stats"]["used_count"]))
-    print("[=] ____updated_count: {}".format(payload["stats"]["updated_count"]))
-    print("[=] ____up_vote: {}".format(payload["stats"]["up_vote"]))
-    print("[=] ____down_vote: {}".format(payload["stats"]["down_vote"]))
-
-
 def see_content(payload):
     """
+    A method to print or not the content
 
     :param payload:
     :return:
@@ -70,17 +64,23 @@ def see_content(payload):
 
 def see_stats(payload):
     """
+    Just a print for stats on a b4sh
 
     :param payload:
     :return:
     """
     choice = input("\n[?] > See stats (used, votes...) ? (Y/N): ")
     if choice.lower() == "y" or choice.lower() == "yes":
-        get_stats(payload["result"])
+        print("[=] Stats:")
+        print("[=] ____used_count: {}".format(payload["result"]["stats"]["used_count"]))
+        print("[=] ____updated_count: {}".format(payload["result"]["stats"]["updated_count"]))
+        print("[=] ____up_vote: {}".format(payload["result"]["stats"]["up_vote"]))
+        print("[=] ____down_vote: {}".format(payload["result"]["stats"]["down_vote"]))
 
 
 def run_content(payload):
     """
+    To run the content of a b4sh
 
     :param payload:
     :return:
@@ -94,6 +94,7 @@ def run_content(payload):
 
 def payload_info(key, payload):
     """
+    This method will get infos of a payload
 
     :param key:
     :param payload:
@@ -110,19 +111,22 @@ def payload_info(key, payload):
 
 def print_results(content: dict):
     """
+    Listing results of a request
 
     :param content:
     :return:
     """
     print("[+] Listing results ({}) :".format(len(content["result"])))
-    for index, elt in enumerate(content["result"]):
-        print("[-] {}-) {}".format(index + 1, elt["key"]))
+    # for index, elt in enumerate(content["result"]):
+    #     print("[-] {}-) {}".format(index + 1, elt["key"]))
+    list_columns(content["result"])
 
     return int(input("\n[?] Your choice (0 to quit):"))
 
 
 def preset_conf(conf_path: str, conf: dict = {}) -> dict:
     """
+    This method is for setting pre-configuration
 
     :param conf_path:
     :param conf:
@@ -143,6 +147,7 @@ def preset_conf(conf_path: str, conf: dict = {}) -> dict:
 
 def ask_set_conf():
     """
+    Just to ask if yes or no we should set conf for unexistance configurations
 
     :return:
     """
@@ -157,6 +162,7 @@ def ask_set_conf():
 
 def get_content():
     """
+    To get the input content
 
     :return:
     """
@@ -180,13 +186,16 @@ def get_format_payload(conf: dict, content_file_path: str = "") -> dict:
     :param content_file_path:
     :return:
     """
-    payload = {"author": conf["author"], "title": rlinput("[?] Title : ", content_file_path.replace("./", "")),
-               "description": input("[?] Description : ")}
+    payload = {
+        "author": conf["author"],
+        "title": rlinput("[?] Title : ", content_file_path.replace("./", "")),
+        "description": input("[?] Description : ")
+    }
     if len(content_file_path) > 2:
         # we check if the path of the shell file exist
         if not path.exists(content_file_path):
             print("[x] The file-path you provided is not correct !")
-            print("[-] Try to write your commands mannualy !")
+            print("[-] Try to write your commands manually !")
             payload["content"] = get_content()
         else:
             print("[+] Getting the content...")
@@ -206,7 +215,7 @@ def paste_help():
     :return:
     """
     print("""
-usage: bh [-h] [-g GET] [-f FIND] [-c CREATE] [-ls LIST] [-v]
+usage: b (or b4sh) [-h] [-g GET] [-f FIND] [-c CREATE] [-ls LIST] [-v]
 
 optional arguments:
   -h,  --help    Show this help message and exit.
@@ -217,3 +226,38 @@ optional arguments:
   -ls, --list    To list all available offline/local b4sh shells.
   -v,  --version To get the actual version of b4sh.
     """)
+
+
+def list_columns(obj, cols=4, columnwise=True, gap=4):
+    """
+    Print the given list in evenly-spaced columns.
+
+    Parameters
+    ----------
+    obj : list
+        The list to be printed.
+    cols : int
+        The number of columns in which the list should be printed.
+    columnwise : bool, default=True
+        If True, the items in the list will be printed column-wise.
+        If False the items in the list will be printed row-wise.
+    gap : int
+        The number of spaces that should separate the longest column
+        item/s from the next column. This is the effective spacing
+        between columns based on the maximum len() of the list items.
+    """
+
+    sobj = [" " + str(index+1) + "-) " + str(item["key"]) for index, item in enumerate(obj)]
+    if cols > len(sobj):
+        cols = len(sobj)
+    max_len = max([len(item) for item in sobj])
+    if columnwise:
+        cols = int(ceil(float(len(sobj)) / float(cols)))
+    plist = [sobj[i: i+cols] for i in range(0, len(sobj), cols)]
+    if columnwise:
+        if not len(plist[-1]) == cols:
+            plist[-1].extend(['']*(len(sobj) - len(plist[-1])))
+        plist = zip(*plist)
+    printer = '\n'.join([''.join([c.ljust(max_len + gap) for c in p]) for p in plist])
+
+    print(printer)
